"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const fs_1 = tslib_1.__importDefault(require("fs"));
const path_1 = tslib_1.__importDefault(require("path"));
const conditions_util_1 = require("./utils/conditions.util");
const currentDirPath = process.cwd();
const encoding = 'utf8';
function getInfo() {
    const fileNames = getFiles(currentDirPath);
    if (!fileNames.length) {
        return { fileInfo: 0, lineInfo: { total: 0, empty: 0, written: 0 } };
    }
    const linesInfo = fileNames
        .map(filename => {
        const currentFile = fs_1.default.readFileSync(path_1.default.join(currentDirPath, filename), encoding).split(/\r?\n/);
        const emptyLines = currentFile.filter(line => !line.length).length;
        const lineInfo = { total: currentFile.length, empty: emptyLines, written: currentFile.length - emptyLines };
        return lineInfo;
    })
        .reduce((a, v) => {
        return { total: a.total + v.total, empty: a.empty + v.empty, written: a.written + v.total - v.empty };
    });
    return { fileInfo: fileNames.length, lineInfo: linesInfo };
}
exports.getInfo = getInfo;
function getFiles(dirPath) {
    const filesAndDirsInCurrentDir = fs_1.default.readdirSync(dirPath);
    const flattedAndFilteredDirs = filesAndDirsInCurrentDir
        .filter(dir => conditions_util_1.hasValidExtensions(dir, dirPath))
        .flatMap(dir => fs_1.default.statSync(path_1.default.join(dirPath, dir)).isDirectory() ? getFiles(path_1.default.join(dirPath, dir)) : mapCurrentDir(dirPath) + dir);
    return flattedAndFilteredDirs;
}
function mapCurrentDir(dirPath) {
    const dir = dirPath !== currentDirPath ? dirPath.slice(currentDirPath.length + 1) : './';
    return dir.endsWith('/') ? dir : dir + '/';
}
